@@ -25,6 +25,7 @@ __all__ = ("ListRetainedMessagesPaginatorName", "ServiceName", "PaginatorName")
 ListRetainedMessagesPaginatorName = Literal["list_retained_messages"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -57,6 +58,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
